==> qtsensors-opensource-src_5.2.1+dfsg.orig.tar.xz: qtsensors-opensource-src-5.2.1/src/plugins/sensorgestures/qtsensors/qtsensorgestureplugin.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QTSENSORGESTURESPLUGIN_H
#define QTSENSORGESTURESPLUGIN_H

#include <QObject>
#include <QStringList>

#include <qsensorgestureplugininterface.h>

QT_BEGIN_NAMESPACE

class QtSensorGesturePlugin : public QObject, public QSensorGesturePluginInterface
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.QSensorGesturePluginInterface")
    Q_INTERFACES(QSensorGesturePluginInterface)

public:
    explicit QtSensorGesturePlugin();
    ~QtSensorGesturePlugin();
    QList <QSensorGestureRecognizer *> createRecognizers() Q_DECL_OVERRIDE;

    QStringList gestureSignals() const;
    QStringList supportedIds() const Q_DECL_OVERRIDE;
    QString name() const Q_DECL_OVERRIDE { return "QtSensorGestures"; }

};

QT_END_NAMESPACE
#endif // QTSENSORGESTURESPLUGIN_H

==> qtsensors-opensource-src_5.4.1+dfsg.orig.tar.xz: qtsensors-opensource-src-5.4.1/src/plugins/sensorgestures/qtsensors/qtsensorgestureplugin.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL21$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia. For licensing terms and
** conditions see http://qt.digia.com/licensing. For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file. Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights. These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QTSENSORGESTURESPLUGIN_H
#define QTSENSORGESTURESPLUGIN_H

#include <QObject>
#include <QStringList>

#include <QtSensors/qsensorgestureplugininterface.h>

QT_BEGIN_NAMESPACE

class QtSensorGesturePlugin : public QObject, public QSensorGesturePluginInterface
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.QSensorGesturePluginInterface")
    Q_INTERFACES(QSensorGesturePluginInterface)

public:
    explicit QtSensorGesturePlugin();
    ~QtSensorGesturePlugin();
    QList <QSensorGestureRecognizer *> createRecognizers() Q_DECL_OVERRIDE;

    QStringList gestureSignals() const;
    QStringList supportedIds() const Q_DECL_OVERRIDE;
    QString name() const Q_DECL_OVERRIDE { return "QtSensorGestures"; }

};

QT_END_NAMESPACE
#endif // QTSENSORGESTURESPLUGIN_H
